print("import: 'nitime'")
import nitime

print("import: 'nitime.algorithms'")
import nitime.algorithms

print("import: 'nitime.algorithms.tests'")
import nitime.algorithms.tests

print("import: 'nitime.analysis'")
import nitime.analysis

print("import: 'nitime.analysis.tests'")
import nitime.analysis.tests

print("import: 'nitime.fmri'")
import nitime.fmri

print("import: 'nitime.fmri.tests'")
import nitime.fmri.tests

print("import: 'nitime.tests'")
import nitime.tests

